@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Bencher::Scenario;
 
 our $DATE = '2016-01-20'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -13,7 +13,6 @@ has sample_bench => (is=>'rw');
 sub mvp_multivalue_args { qw(sample_bench) }
 
 use Bencher;
-use List::MoreUtils qw(firstidx);
 use Perinci::Sub::ConvertArgs::Argv qw(convert_args_to_argv);
 use String::ShellQuote;
 
@@ -201,8 +200,14 @@ sub _process_module {
 
         for my $mod (@modules) {
             push @pod, "L<$mod>";
-            my $v = firstidx {$_->[3]{'func.module_versions'}{$mod}} @bench_res;
-            if ($v) {
+            my $v;
+            for (@bench_res) {
+                if (defined $_->[3]{'func.module_versions'}{$mod}) {
+                    $v = $_->[3]{'func.module_versions'}{$mod};
+                    last;
+                }
+            }
+            if (defined $v) {
                 push @pod, " ", __ver_or_vers($v);
             }
             push @pod, "\n\n";
@@ -230,8 +235,9 @@ sub _process_module {
             $i++;
             my $p0 = $scenario->{participants}[$i];
             push @pod, "=item * ", ($p->{name} // ''), " ($p->{type})",
-                ($p->{include_by_default} ? "" : " (not included by default)"),
-                "\n\n";
+                ($p->{include_by_default} ? "" : " (not included by default)");
+            push @pod, " [".join(", ", @{$p->{tags}})."]" if $p->{tags};
+            push @pod, "\n\n";
             if ($p0->{summary}) {
                 push @pod, $p0->{summary}, ".\n\n";
             }
@@ -269,7 +275,9 @@ sub _process_module {
 
         push @pod, "=over\n\n";
         for my $ds (@{ $scenario->{datasets} }) {
-            push @pod, "=item * $ds->{name}\n\n";
+            push @pod, "=item * $ds->{name}";
+            push @pod, " [".join(", ", @{$ds->{tags}})."]" if $ds->{tags};
+            push @pod, "\n\n";
             push @pod, "$ds->{summary}\n\n" if $ds->{summary};
         }
         push @pod, "=back\n\n";
@@ -312,7 +320,7 @@ Pod::Weaver::Plugin::Bencher::Scenario - Plugin to use when building Bencher::Sc
 
 =head1 VERSION
 
-This document describes version 0.08 of Pod::Weaver::Plugin::Bencher::Scenario (from Perl distribution Pod-Weaver-Plugin-Bencher-Scenario), released on 2016-01-20.
+This document describes version 0.09 of Pod::Weaver::Plugin::Bencher::Scenario (from Perl distribution Pod-Weaver-Plugin-Bencher-Scenario), released on 2016-01-20.
 
 =head1 SYNOPSIS
 
